"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRealToken1Amount = exports.getRealToken0Amount = exports.getRealReceivePriceWithDexFee = exports.getRealPriceWithDexFee = exports.getRealPrice = exports.valueToUSD = exports.valueToPercentage = exports.bigNumberToWeb3Input = exports.divDecimals = exports.timesDecimals = void 0;
const bignumber_js_1 = __importDefault(require("bignumber.js"));
const misc_1 = require("./constants/misc");
function timesDecimals(a, decimals) {
    if (!a)
        return misc_1.ZERO;
    const bigA = bignumber_js_1.default.isBigNumber(a) ? a : new bignumber_js_1.default(a || '');
    if (bigA.isNaN())
        return misc_1.ZERO;
    if (typeof decimals === 'string' && decimals.length > 10) {
        return bigA.times(decimals);
    }
    return bigA.times(`1e${decimals !== null && decimals !== void 0 ? decimals : 18}`);
}
exports.timesDecimals = timesDecimals;
function divDecimals(a, decimals) {
    if (!a)
        return misc_1.ZERO;
    const bigA = bignumber_js_1.default.isBigNumber(a) ? a : new bignumber_js_1.default(a || '');
    if (bigA.isNaN())
        return misc_1.ZERO;
    if (typeof decimals === 'string' && decimals.length > 10) {
        return bigA.div(decimals);
    }
    return bigA.div(`1e${decimals !== null && decimals !== void 0 ? decimals : 18}`);
}
exports.divDecimals = divDecimals;
function bigNumberToWeb3Input(input) {
    return bignumber_js_1.default.isBigNumber(input) ? input.toFixed(0) : new bignumber_js_1.default(input).toFixed(0);
}
exports.bigNumberToWeb3Input = bigNumberToWeb3Input;
function valueToPercentage(input) {
    return bignumber_js_1.default.isBigNumber(input) ? input.times(100) : timesDecimals(input, 2);
}
exports.valueToPercentage = valueToPercentage;
function valueToUSD(input) {
    if (!bignumber_js_1.default.isBigNumber) {
        throw new Error('input not is number');
    }
    const bgInput = new bignumber_js_1.default(input);
    if (bgInput.gte(misc_1.VALUE_T)) {
        return bgInput.div(misc_1.VALUE_T).toFormat(2);
    }
    if (bgInput.gte(misc_1.VALUE_B)) {
        return bgInput.div(misc_1.VALUE_B).toFormat(2);
    }
    if (bgInput.gte(misc_1.VALUE_M)) {
        return bgInput.div(misc_1.VALUE_M).toFormat(2);
    }
    return bgInput.toFormat(2);
}
exports.valueToUSD = valueToUSD;
const getRealPrice = ({ side, token0Amount = 0, token1Amount = 0, feeRate = 0 }) => {
    const average = misc_1.ZERO.plus(token1Amount).div(token0Amount);
    if (side === 0) {
        return average.multipliedBy(misc_1.ONE.minus(feeRate)).toFixed();
    }
    else {
        return average.div(misc_1.ONE.minus(feeRate)).toFixed();
    }
};
exports.getRealPrice = getRealPrice;
const getRealPriceWithDexFee = ({ side, token0Amount = 0, token1Amount = 0, dexFee = 0, }) => {
    if (side === 0) {
        return misc_1.ZERO.plus(token1Amount).minus(dexFee).div(token0Amount);
    }
    else if (side === 1) {
        return misc_1.ZERO.plus(token1Amount).div(misc_1.ZERO.plus(token0Amount).minus(dexFee));
    }
    else {
        return misc_1.ZERO.plus(token0Amount).minus(dexFee).div(token1Amount);
    }
};
exports.getRealPriceWithDexFee = getRealPriceWithDexFee;
const getRealReceivePriceWithDexFee = ({ side, token0Amount = 0, token1Amount = 0, dexFee = 0, }) => {
    if (side === 0) {
        return misc_1.ZERO.plus(token1Amount).minus(dexFee).div(token0Amount);
    }
    else {
        return misc_1.ZERO.plus(token0Amount).minus(dexFee).div(token1Amount);
    }
};
exports.getRealReceivePriceWithDexFee = getRealReceivePriceWithDexFee;
const getRealToken0Amount = ({ side, value = 0, feeRate = 0, decimals = 8 }) => {
    return side === 0 ? value : misc_1.ZERO.plus(value).multipliedBy(misc_1.ONE.minus(feeRate)).dp(decimals).toFixed();
};
exports.getRealToken0Amount = getRealToken0Amount;
const getRealToken1Amount = ({ side, value = 0, feeRate = 0, decimals = 8 }) => {
    return side === 1 ? value : misc_1.ZERO.plus(value).multipliedBy(misc_1.ONE.minus(feeRate)).dp(decimals).toFixed();
};
exports.getRealToken1Amount = getRealToken1Amount;
