"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.showValueWrapper = exports.formatTrillion = exports.formatBillion = exports.formatMillion = exports.formatThousand = exports.formatPriceByStringToDp = exports.formatPriceByNumberToDp = exports.formatPriceByStringToFix = exports.formatPriceByNumberToFix = exports.formatPercentage = exports.formatBalance = exports.formatLiquidity = exports.formatPriceChangeSD = exports.formatPriceChange = exports.formatTokenAmount = exports.formatPriceSplit = exports.getPriceScale = exports.formatPrice = exports.formatPriceUSDSplit = exports.formatPriceUSDWithSymBol = exports.formatPriceUSD = exports.ONE = exports.ZERO = void 0;
const bignumber_js_1 = __importDefault(require("bignumber.js"));
exports.ZERO = new bignumber_js_1.default(0);
exports.ONE = new bignumber_js_1.default(1);
const ONE_THOUSAND = new bignumber_js_1.default(1000);
const ONE_MILLION = new bignumber_js_1.default(1000000);
const ONE_BILLION = new bignumber_js_1.default(1000000000);
const ONE_TRILLION = new bignumber_js_1.default(1000000000000);
function formatPriceUSD(price, digits = 12) {
    // if (!isShowUSD()) {
    //   return '';
    // }
    if (!price) {
        return exports.ZERO.toString();
    }
    const bigNum = new bignumber_js_1.default(price);
    if (bigNum.isNaN())
        return '0';
    if (bigNum.gte(ONE_TRILLION)) {
        return formatTrillion(price);
    }
    if (bigNum.gte(ONE_BILLION)) {
        return formatBillion(bigNum);
    }
    if (bigNum.gte(ONE_MILLION)) {
        return formatMillion(bigNum);
    }
    if (bigNum.gte(0.1)) {
        return bigNum.dp(2, bignumber_js_1.default.ROUND_DOWN).toString();
    }
    return bigNum.dp(digits).precision(3, bignumber_js_1.default.ROUND_DOWN).toString();
}
exports.formatPriceUSD = formatPriceUSD;
function formatPriceUSDWithSymBol(price, prefix = '', suffix = '') {
    // if (!isShowUSD()) {
    //   return '-';
    // }
    return `${prefix}$${formatPriceUSD(price, 3)}${suffix}`;
}
exports.formatPriceUSDWithSymBol = formatPriceUSDWithSymBol;
function formatPriceUSDSplit(price) {
    const bigNum = new bignumber_js_1.default(price);
    if (bigNum.isNaN())
        return { p: '0' };
    if (bigNum.gte(0.1))
        return { p: formatPriceUSD(price, 3) };
    return formatNumber(price, 12, 3);
}
exports.formatPriceUSDSplit = formatPriceUSDSplit;
function formatPrice(price, digits = 12) {
    if (!price) {
        return exports.ZERO.toString();
    }
    const bigNum = new bignumber_js_1.default(price);
    if (bigNum.gte(ONE_TRILLION)) {
        return formatTrillion(price);
    }
    if (bigNum.gte(ONE_BILLION)) {
        return formatBillion(bigNum);
    }
    if (bigNum.gte(ONE_MILLION)) {
        return formatMillion(bigNum);
    }
    if (bigNum.gte(10)) {
        return bigNum.dp(2).toString();
    }
    if (bigNum.gte(0.0001)) {
        return bigNum.dp(4).toString();
    }
    return bigNum.precision(4).dp(digits).toString();
}
exports.formatPrice = formatPrice;
const OMIT_ZERO_DIGITS = 6;
const formatNumber = (value, digits = 12, last = 4) => {
    var _a;
    const n = new bignumber_js_1.default(value);
    if (n.e === null || n.e === null)
        return { p: '0' };
    const zeros = exports.ONE.plus(n.e).abs();
    if (zeros.gte(digits))
        return { p: '0' };
    if (zeros.lt(OMIT_ZERO_DIGITS))
        return {
            p: n.dp(digits).precision(last).toString(),
        };
    const o = zeros.minus(1);
    const lastNumber = (_a = n.c) === null || _a === void 0 ? void 0 : _a.join('');
    // const last = ZERO.plus(digits).minus(o).minus(1).toNumber();
    const m = lastNumber === null || lastNumber === void 0 ? void 0 : lastNumber.slice(0, last);
    return {
        p: '0.0',
        o: o.toString(),
        m,
    };
};
const getPriceScale = (price, max = 12) => {
    const bigNum = new bignumber_js_1.default(price);
    if (bigNum.gte(10))
        return 2;
    if (bigNum.gte(1e-4))
        return 4;
    const { e } = bigNum;
    if (!e)
        return 4;
    const d = exports.ONE.plus(e).abs().toNumber() + 4;
    if (d > max)
        return 12;
    return d;
};
exports.getPriceScale = getPriceScale;
function formatPriceSplit(price = 0, digits = 12) {
    const bigNum = new bignumber_js_1.default(price);
    if (bigNum.gte(1))
        return { p: formatPrice(price, digits) };
    return formatNumber(price, digits);
}
exports.formatPriceSplit = formatPriceSplit;
function formatTokenAmount(num, digits) {
    if (!num) {
        return exports.ZERO.toString();
    }
    const bigNum = new bignumber_js_1.default(num);
    if (bigNum.gte(ONE_TRILLION)) {
        return formatTrillion(bigNum);
    }
    if (bigNum.gte(ONE_BILLION)) {
        return formatBillion(bigNum);
    }
    if (bigNum.gte(ONE_MILLION)) {
        return formatMillion(bigNum);
    }
    if (bigNum.gte(ONE_THOUSAND)) {
        return formatThousand(bigNum);
    }
    // NFT
    if (digits === 0) {
        return bigNum.toFixed(0);
    }
    if (bigNum.gte(0.1)) {
        return bigNum.toFixed(2);
    }
    return bigNum.dp(digits !== null && digits !== void 0 ? digits : 4).toString();
}
exports.formatTokenAmount = formatTokenAmount;
function formatPriceChange(price, digits = 12) {
    if (!price) {
        return exports.ZERO.toString();
    }
    const bigNum = new bignumber_js_1.default(price);
    if (bigNum.isNaN())
        return '0';
    if (digits === 0)
        return bigNum.dp(digits).toString();
    if (bigNum.gte(10)) {
        return bigNum.dp(2).toString();
    }
    if (bigNum.gte(0.0001)) {
        return bigNum.dp(4).toString();
    }
    return bigNum.precision(4).dp(digits).toString();
}
exports.formatPriceChange = formatPriceChange;
function formatPriceChangeSD(price, digits = 12) {
    if (!price) {
        return exports.ZERO.toString();
    }
    const bigNum = new bignumber_js_1.default(price);
    if (bigNum.gte(10)) {
        return bigNum.dp(2).toString();
    }
    if (bigNum.gte(1)) {
        return bigNum.dp(4).toString();
    }
    return bigNum.sd(digits).toString();
}
exports.formatPriceChangeSD = formatPriceChangeSD;
function formatLiquidity(price, digits = 8) {
    if (!price) {
        return exports.ZERO.toString();
    }
    const bigNum = new bignumber_js_1.default(price);
    if (bigNum.gte(ONE_BILLION)) {
        return formatBillion(bigNum);
    }
    if (bigNum.gte(ONE_MILLION)) {
        return formatMillion(bigNum);
    }
    return bigNum.dp(digits).toString();
}
exports.formatLiquidity = formatLiquidity;
function formatBalance(price) {
    if (!price) {
        return exports.ZERO.toString();
    }
    const bigNum = new bignumber_js_1.default(price);
    return bigNum.toFormat(8);
}
exports.formatBalance = formatBalance;
function formatPercentage(price) {
    if (!price) {
        return exports.ZERO.toString();
    }
    return formatPriceByStringToFix(price, 2);
}
exports.formatPercentage = formatPercentage;
function formatPriceByNumberToFix(price, digits = 2) {
    if (!price) {
        return 0;
    }
    const bigNum = new bignumber_js_1.default(price);
    return new bignumber_js_1.default(bigNum.toFixed(digits)).toNumber();
}
exports.formatPriceByNumberToFix = formatPriceByNumberToFix;
function formatPriceByStringToFix(price, digits = 2) {
    if (!price) {
        return '';
    }
    const bigNum = new bignumber_js_1.default(price);
    return bigNum.toFormat(digits);
}
exports.formatPriceByStringToFix = formatPriceByStringToFix;
function formatPriceByNumberToDp(price, digits = 2) {
    if (!price) {
        return 0;
    }
    const bigNum = new bignumber_js_1.default(price);
    return bigNum.dp(digits).toNumber();
}
exports.formatPriceByNumberToDp = formatPriceByNumberToDp;
function formatPriceByStringToDp(price, digits = 2) {
    if (!price) {
        return '';
    }
    const bigNum = new bignumber_js_1.default(price);
    return bigNum.dp(digits).toString();
}
exports.formatPriceByStringToDp = formatPriceByStringToDp;
function formatThousand(price) {
    if (!price) {
        return exports.ZERO.toString();
    }
    return `${new bignumber_js_1.default(price).div(ONE_THOUSAND).toFixed(2)}K`;
}
exports.formatThousand = formatThousand;
function formatMillion(price) {
    if (!price) {
        return exports.ZERO.toString();
    }
    return `${new bignumber_js_1.default(price).div(ONE_MILLION).toFixed(2)}M`;
}
exports.formatMillion = formatMillion;
function formatBillion(price) {
    if (!price) {
        return exports.ZERO.toString();
    }
    return `${new bignumber_js_1.default(price).div(ONE_BILLION).toFixed(2)}B`;
}
exports.formatBillion = formatBillion;
function formatTrillion(price) {
    if (!price) {
        return exports.ZERO.toString();
    }
    if (new bignumber_js_1.default(price).gte(ONE_TRILLION.times(1000))) {
        return '>999T';
    }
    return `${new bignumber_js_1.default(price).div(ONE_TRILLION).toFixed(2)}T`;
}
exports.formatTrillion = formatTrillion;
const showValueWrapper = (originValue, returnValue, defaultValue = '--') => {
    if (typeof originValue === 'undefined' || originValue === null)
        return defaultValue;
    return returnValue;
};
exports.showValueWrapper = showValueWrapper;
