import BigNumber from 'bignumber.js';
import { ZERO, VALUE_B, VALUE_M, VALUE_T, ONE } from './constants/misc.js';
export function timesDecimals(a, decimals) {
    if (!a)
        return ZERO;
    const bigA = BigNumber.isBigNumber(a) ? a : new BigNumber(a || '');
    if (bigA.isNaN())
        return ZERO;
    if (typeof decimals === 'string' && decimals.length > 10) {
        return bigA.times(decimals);
    }
    return bigA.times(`1e${decimals !== null && decimals !== void 0 ? decimals : 18}`);
}
export function divDecimals(a, decimals) {
    if (!a)
        return ZERO;
    const bigA = BigNumber.isBigNumber(a) ? a : new BigNumber(a || '');
    if (bigA.isNaN())
        return ZERO;
    if (typeof decimals === 'string' && decimals.length > 10) {
        return bigA.div(decimals);
    }
    return bigA.div(`1e${decimals !== null && decimals !== void 0 ? decimals : 18}`);
}
export function bigNumberToWeb3Input(input) {
    return BigNumber.isBigNumber(input) ? input.toFixed(0) : new BigNumber(input).toFixed(0);
}
export function valueToPercentage(input) {
    return BigNumber.isBigNumber(input) ? input.times(100) : timesDecimals(input, 2);
}
export function valueToUSD(input) {
    if (!BigNumber.isBigNumber) {
        throw new Error('input not is number');
    }
    const bgInput = new BigNumber(input);
    if (bgInput.gte(VALUE_T)) {
        return bgInput.div(VALUE_T).toFormat(2);
    }
    if (bgInput.gte(VALUE_B)) {
        return bgInput.div(VALUE_B).toFormat(2);
    }
    if (bgInput.gte(VALUE_M)) {
        return bgInput.div(VALUE_M).toFormat(2);
    }
    return bgInput.toFormat(2);
}
export const getRealPrice = ({ side, token0Amount = 0, token1Amount = 0, feeRate = 0 }) => {
    const average = ZERO.plus(token1Amount).div(token0Amount);
    if (side === 0) {
        return average.multipliedBy(ONE.minus(feeRate)).toFixed();
    }
    else {
        return average.div(ONE.minus(feeRate)).toFixed();
    }
};
export const getRealPriceWithDexFee = ({ side, token0Amount = 0, token1Amount = 0, dexFee = 0, }) => {
    if (side === 0) {
        return ZERO.plus(token1Amount).minus(dexFee).div(token0Amount);
    }
    else if (side === 1) {
        return ZERO.plus(token1Amount).div(ZERO.plus(token0Amount).minus(dexFee));
    }
    else {
        return ZERO.plus(token0Amount).minus(dexFee).div(token1Amount);
    }
};
export const getRealReceivePriceWithDexFee = ({ side, token0Amount = 0, token1Amount = 0, dexFee = 0, }) => {
    if (side === 0) {
        return ZERO.plus(token1Amount).minus(dexFee).div(token0Amount);
    }
    else {
        return ZERO.plus(token0Amount).minus(dexFee).div(token1Amount);
    }
};
export const getRealToken0Amount = ({ side, value = 0, feeRate = 0, decimals = 8 }) => {
    return side === 0 ? value : ZERO.plus(value).multipliedBy(ONE.minus(feeRate)).dp(decimals).toFixed();
};
export const getRealToken1Amount = ({ side, value = 0, feeRate = 0, decimals = 8 }) => {
    return side === 1 ? value : ZERO.plus(value).multipliedBy(ONE.minus(feeRate)).dp(decimals).toFixed();
};
