import BigNumber from 'bignumber.js';
export const ZERO = new BigNumber(0);
export const ONE = new BigNumber(1);
const ONE_THOUSAND = new BigNumber(1000);
const ONE_MILLION = new BigNumber(1000000);
const ONE_BILLION = new BigNumber(1000000000);
const ONE_TRILLION = new BigNumber(1000000000000);
export function formatPriceUSD(price, digits = 12) {
    // if (!isShowUSD()) {
    //   return '';
    // }
    if (!price) {
        return ZERO.toString();
    }
    const bigNum = new BigNumber(price);
    if (bigNum.isNaN())
        return '0';
    if (bigNum.gte(ONE_TRILLION)) {
        return formatTrillion(price);
    }
    if (bigNum.gte(ONE_BILLION)) {
        return formatBillion(bigNum);
    }
    if (bigNum.gte(ONE_MILLION)) {
        return formatMillion(bigNum);
    }
    if (bigNum.gte(0.1)) {
        return bigNum.dp(2, BigNumber.ROUND_DOWN).toString();
    }
    return bigNum.dp(digits).precision(3, BigNumber.ROUND_DOWN).toString();
}
export function formatPriceUSDWithSymBol(price, prefix = '', suffix = '') {
    // if (!isShowUSD()) {
    //   return '-';
    // }
    return `${prefix}$${formatPriceUSD(price, 3)}${suffix}`;
}
export function formatPriceUSDSplit(price) {
    const bigNum = new BigNumber(price);
    if (bigNum.isNaN())
        return { p: '0' };
    if (bigNum.gte(0.1))
        return { p: formatPriceUSD(price, 3) };
    return formatNumber(price, 12, 3);
}
export function formatPrice(price, digits = 12) {
    if (!price) {
        return ZERO.toString();
    }
    const bigNum = new BigNumber(price);
    if (bigNum.gte(ONE_TRILLION)) {
        return formatTrillion(price);
    }
    if (bigNum.gte(ONE_BILLION)) {
        return formatBillion(bigNum);
    }
    if (bigNum.gte(ONE_MILLION)) {
        return formatMillion(bigNum);
    }
    if (bigNum.gte(10)) {
        return bigNum.dp(2).toString();
    }
    if (bigNum.gte(0.0001)) {
        return bigNum.dp(4).toString();
    }
    return bigNum.precision(4).dp(digits).toString();
}
const OMIT_ZERO_DIGITS = 6;
const formatNumber = (value, digits = 12, last = 4) => {
    var _a;
    const n = new BigNumber(value);
    if (n.e === null || n.e === null)
        return { p: '0' };
    const zeros = ONE.plus(n.e).abs();
    if (zeros.gte(digits))
        return { p: '0' };
    if (zeros.lt(OMIT_ZERO_DIGITS))
        return {
            p: n.dp(digits).precision(last).toString(),
        };
    const o = zeros.minus(1);
    const lastNumber = (_a = n.c) === null || _a === void 0 ? void 0 : _a.join('');
    // const last = ZERO.plus(digits).minus(o).minus(1).toNumber();
    const m = lastNumber === null || lastNumber === void 0 ? void 0 : lastNumber.slice(0, last);
    return {
        p: '0.0',
        o: o.toString(),
        m,
    };
};
export const getPriceScale = (price, max = 12) => {
    const bigNum = new BigNumber(price);
    if (bigNum.gte(10))
        return 2;
    if (bigNum.gte(1e-4))
        return 4;
    const { e } = bigNum;
    if (!e)
        return 4;
    const d = ONE.plus(e).abs().toNumber() + 4;
    if (d > max)
        return 12;
    return d;
};
export function formatPriceSplit(price = 0, digits = 12) {
    const bigNum = new BigNumber(price);
    if (bigNum.gte(1))
        return { p: formatPrice(price, digits) };
    return formatNumber(price, digits);
}
export function formatTokenAmount(num, digits) {
    if (!num) {
        return ZERO.toString();
    }
    const bigNum = new BigNumber(num);
    if (bigNum.gte(ONE_TRILLION)) {
        return formatTrillion(bigNum);
    }
    if (bigNum.gte(ONE_BILLION)) {
        return formatBillion(bigNum);
    }
    if (bigNum.gte(ONE_MILLION)) {
        return formatMillion(bigNum);
    }
    if (bigNum.gte(ONE_THOUSAND)) {
        return formatThousand(bigNum);
    }
    // NFT
    if (digits === 0) {
        return bigNum.toFixed(0);
    }
    if (bigNum.gte(0.1)) {
        return bigNum.toFixed(2);
    }
    return bigNum.dp(digits !== null && digits !== void 0 ? digits : 4).toString();
}
export function formatPriceChange(price, digits = 12) {
    if (!price) {
        return ZERO.toString();
    }
    const bigNum = new BigNumber(price);
    if (bigNum.isNaN())
        return '0';
    if (digits === 0)
        return bigNum.dp(digits).toString();
    if (bigNum.gte(10)) {
        return bigNum.dp(2).toString();
    }
    if (bigNum.gte(0.0001)) {
        return bigNum.dp(4).toString();
    }
    return bigNum.precision(4).dp(digits).toString();
}
export function formatPriceChangeSD(price, digits = 12) {
    if (!price) {
        return ZERO.toString();
    }
    const bigNum = new BigNumber(price);
    if (bigNum.gte(10)) {
        return bigNum.dp(2).toString();
    }
    if (bigNum.gte(1)) {
        return bigNum.dp(4).toString();
    }
    return bigNum.sd(digits).toString();
}
export function formatLiquidity(price, digits = 8) {
    if (!price) {
        return ZERO.toString();
    }
    const bigNum = new BigNumber(price);
    if (bigNum.gte(ONE_BILLION)) {
        return formatBillion(bigNum);
    }
    if (bigNum.gte(ONE_MILLION)) {
        return formatMillion(bigNum);
    }
    return bigNum.dp(digits).toString();
}
export function formatBalance(price) {
    if (!price) {
        return ZERO.toString();
    }
    const bigNum = new BigNumber(price);
    return bigNum.toFormat(8);
}
export function formatPercentage(price) {
    if (!price) {
        return ZERO.toString();
    }
    return formatPriceByStringToFix(price, 2);
}
export function formatPriceByNumberToFix(price, digits = 2) {
    if (!price) {
        return 0;
    }
    const bigNum = new BigNumber(price);
    return new BigNumber(bigNum.toFixed(digits)).toNumber();
}
export function formatPriceByStringToFix(price, digits = 2) {
    if (!price) {
        return '';
    }
    const bigNum = new BigNumber(price);
    return bigNum.toFormat(digits);
}
export function formatPriceByNumberToDp(price, digits = 2) {
    if (!price) {
        return 0;
    }
    const bigNum = new BigNumber(price);
    return bigNum.dp(digits).toNumber();
}
export function formatPriceByStringToDp(price, digits = 2) {
    if (!price) {
        return '';
    }
    const bigNum = new BigNumber(price);
    return bigNum.dp(digits).toString();
}
export function formatThousand(price) {
    if (!price) {
        return ZERO.toString();
    }
    return `${new BigNumber(price).div(ONE_THOUSAND).toFixed(2)}K`;
}
export function formatMillion(price) {
    if (!price) {
        return ZERO.toString();
    }
    return `${new BigNumber(price).div(ONE_MILLION).toFixed(2)}M`;
}
export function formatBillion(price) {
    if (!price) {
        return ZERO.toString();
    }
    return `${new BigNumber(price).div(ONE_BILLION).toFixed(2)}B`;
}
export function formatTrillion(price) {
    if (!price) {
        return ZERO.toString();
    }
    if (new BigNumber(price).gte(ONE_TRILLION.times(1000))) {
        return '>999T';
    }
    return `${new BigNumber(price).div(ONE_TRILLION).toFixed(2)}T`;
}
export const showValueWrapper = (originValue, returnValue, defaultValue = '--') => {
    if (typeof originValue === 'undefined' || originValue === null)
        return defaultValue;
    return returnValue;
};
