import { getTokenWeights } from './token.js';
import { ONE, ZERO } from './constants/misc.js';
import BigNumber from 'bignumber.js';
import lodash from 'lodash';
export const sleep = (time) => {
    return new Promise(resolve => {
        setTimeout(() => {
            resolve('sleep');
        }, time);
    });
};
export const unifyWTokenSymbol = (token) => {
    if (!token)
        return '';
    return token.symbol;
};
export function getPairsOrderByTokenWeights(token0, token1) {
    if (!token0 || !token1) {
        return [token0, token1];
    }
    return getTokenWeights(typeof token0 === 'string' ? token0 : token0.symbol) >
        getTokenWeights(typeof token1 === 'string' ? token1 : token1.symbol)
        ? [token1, token0]
        : [token0, token1];
}
export function getPairsLogoOrderByTokenWeights(tokens) {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    if ((!((_a = tokens[0]) === null || _a === void 0 ? void 0 : _a.symbol) && !((_b = tokens[0].currency) === null || _b === void 0 ? void 0 : _b.symbol)) || (!((_c = tokens[1]) === null || _c === void 0 ? void 0 : _c.symbol) && !((_d = tokens[1].currency) === null || _d === void 0 ? void 0 : _d.symbol))) {
        return tokens;
    }
    return getTokenWeights(((_e = tokens[0]) === null || _e === void 0 ? void 0 : _e.symbol) || ((_f = tokens[0].currency) === null || _f === void 0 ? void 0 : _f.symbol)) >
        getTokenWeights(((_g = tokens[1]) === null || _g === void 0 ? void 0 : _g.symbol) || ((_h = tokens[1].currency) === null || _h === void 0 ? void 0 : _h.symbol))
        ? tokens.reverse()
        : tokens;
}
export const getIsReversed = (token0, token1) => {
    return (getTokenWeights(typeof token0 === 'string' ? token0 : token0.symbol) >
        getTokenWeights(typeof token1 === 'string' ? token1 : token1.symbol));
};
export const getPairReversed = (_pair) => {
    if (!getIsReversed(_pair.token0, _pair.token1)) {
        return _pair;
    }
    const pair = lodash.cloneDeep(_pair);
    pair.originToken0 = Object.assign({}, _pair.token0);
    pair.originToken1 = Object.assign({}, _pair.token1);
    const token0 = Object.assign({}, pair.token0);
    const token1 = Object.assign({}, pair.token1);
    pair.token0 = token1;
    pair.token1 = token0;
    pair.valueLocked0 = _pair.valueLocked1;
    pair.valueLocked1 = _pair.valueLocked0;
    pair.price = new BigNumber(_pair.valueLocked0).div(_pair.valueLocked1).toNumber();
    pair.priceUSD = new BigNumber(pair.price).times(_pair.priceUSD).toNumber();
    // TODO
    pair.priceHigh24h = ONE.div(_pair.priceLow24h).toNumber();
    pair.priceLow24h = ONE.div(_pair.priceHigh24h).toNumber();
    pair.priceHigh24hUSD = ZERO.plus(pair.priceHigh24h).times(_pair.priceUSD).toNumber();
    pair.priceLow24hUSD = ZERO.plus(pair.priceLow24h).times(_pair.priceUSD).toNumber();
    pair.priceChange24h = ZERO.minus(_pair.pricePercentChange24h).div(100).div(_pair.price).toNumber();
    pair.pricePercentChange24h = ZERO.minus(_pair.pricePercentChange24h)
        .div(new BigNumber(_pair.pricePercentChange24h).plus(100))
        .times(100)
        .toNumber();
    pair.volume24h = _pair.tradeValue24h;
    pair.tradeValue24h = _pair.volume24h;
    return pair;
};
export function stringCut(str, resultLen) {
    if (!str || typeof str !== 'string') {
        return '';
    }
    if (str.length <= resultLen) {
        return str;
    }
    return str.slice(0, resultLen) + '...';
}
